@@ -11,14 +11,14 @@
  *
  * roccat-tools is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with roccat-tools. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "roccat_config_window.h"
+#include "roccat_config_window_pages.h"
 
 G_BEGIN_DECLS
 
