@@ -8,7 +8,7 @@
  *
  * roccat-tools is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
@@ -19,6 +19,8 @@
 #include "roccat_helper.h"
 #include "roccat_secure.h"
 #include "roccat_warning_dialog.h"
+#include "config.h"
+#include "i18n.h"
 #include <gaminggear/gaminggear.h>
 
 int main(int argc, char **argv) {
@@ -31,6 +33,8 @@ int main(int argc, char **argv) {
 	gtk_init(&argc, &argv);
 	gaminggearwidget_init();
 
+	g_debug(_("Version: %s"), VERSION_STRING);
+
 	(void)nythconfig_window_new();
 
 	gtk_main();
