@@ -8,7 +8,7 @@
  *
  * roccat-tools is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
@@ -225,7 +225,7 @@ static void sensitivity_changed_cb(SavuEventhandlerChannel *channel, guchar x, g
 	notification_type = savu_configuration_get_sensitivity_notification_type(priv->config);
 
 	if (notification_type == ROCCAT_NOTIFICATION_TYPE_OSD)
-		roccat_notification_sensitivity_update(priv->sensitivity_note, notification_type, x - 6, y - 6);
+		roccat_notification_sensitivity_update(priv->sensitivity_note, notification_type, roccat_sensitivity_from_bin_to_value(x), roccat_sensitivity_from_bin_to_value(y));
 	else if (x > priv->actual_sensitivity_x)
 		roccat_notification_sensitivity_update_up(priv->sensitivity_note, notification_type,
 				savu_configuration_get_notification_volume(priv->config));
@@ -272,8 +272,8 @@ static gboolean profile_data_load(SavuEventhandler *eventhandler, GError **error
 static void device_add_cb(RoccatDeviceScannerInterface *interface, RoccatDevice *device, gpointer user_data) {
 	SavuEventhandler *eventhandler = SAVU_EVENTHANDLER(user_data);
 	SavuEventhandlerPrivate *priv = eventhandler->priv;
-	GError *error = NULL;
-	SavuGeneral *general;
+	GError *local_error = NULL;
+	guint driver_state;
 
 	if (priv->device) {
 		g_critical(_("Multiple devices present."));
@@ -286,6 +286,14 @@ static void device_add_cb(RoccatDeviceScannerInterface *interface, RoccatDevice
 
 	configuration_reload(eventhandler);
 
+	driver_state = roccat_eventhandler_host_should_set_driver_state(priv->host);
+	if (driver_state == ROCCATEVENTHANDLER_CONFIGURATION_DRIVER_STATE_ON || driver_state == ROCCATEVENTHANDLER_CONFIGURATION_DRIVER_STATE_OFF) {
+		if (!savu_device_state_write(priv->device, (driver_state == ROCCATEVENTHANDLER_CONFIGURATION_DRIVER_STATE_ON) ? SAVU_DEVICE_STATE_STATE_ON : SAVU_DEVICE_STATE_STATE_OFF, &local_error)) {
+			g_warning(_("Could not correct driver state: %s"), local_error->message);
+			g_clear_error(&local_error);
+		}
+	}
+
 	/* Notificator gets initialized only once if a device is found.
 	 * Gets deinited once in finalizer.
 	 */
@@ -298,28 +306,20 @@ static void device_add_cb(RoccatDeviceScannerInterface *interface, RoccatDevice
 	if (!priv->timer_note)
 		priv->timer_note = roccat_notification_timer_new(roccat_eventhandler_host_get_notificator(priv->host), SAVU_DEVICE_NAME);
 	
-	priv->actual_profile_index = savu_profile_read(priv->device, &error);
-	if (error) {
-		g_warning(_("Could not read actual profile: %s"), error->message);
-		g_clear_error(&error);
-	} else {
-		general = savu_general_read(priv->device, priv->actual_profile_index, &error);
-		if (error) {
-			g_warning(_("Could not read hardware profile data: %s"), error->message);
-			g_clear_error(&error);
-			priv->actual_sensitivity_x = (ROCCAT_SENSITIVITY_MIN + ROCCAT_SENSITIVITY_MAX) >> 1; /* guessing */
-		} else {
-			priv->actual_sensitivity_x = general->sensitivity_x;
-			g_free(general);
-		}
-	}
-	
-	profile_data_load(eventhandler, &error);
-	if (error) {
-		g_warning(_("Could not read profile data: %s"), error->message);
-		g_clear_error(&error);
+	profile_data_load(eventhandler, &local_error);
+	if (local_error) {
+		g_warning(_("Could not read profile data: %s"), local_error->message);
+		g_clear_error(&local_error);
 	}
 
+	priv->actual_profile_index = savu_profile_read(priv->device, &local_error);
+	if (local_error) {
+		g_warning(_("Could not read actual profile: %s"), local_error->message);
+		g_clear_error(&local_error);
+		priv->actual_sensitivity_x = (ROCCAT_SENSITIVITY_MIN + ROCCAT_SENSITIVITY_MAX) >> 1;
+	} else
+		priv->actual_sensitivity_x = savu_rmp_get_sensitivity_x(priv->rmp[priv->actual_profile_index]);
+
 	// FIXME create in init and just disconnect/reconnect?
 	priv->dbus_server = savu_dbus_server_new();
 	g_signal_connect(G_OBJECT(priv->dbus_server), "open-gui", G_CALLBACK(open_gui_cb), eventhandler);
@@ -330,10 +330,10 @@ static void device_add_cb(RoccatDeviceScannerInterface *interface, RoccatDevice
 
 	priv->active_window_changed_handler = g_signal_connect(G_OBJECT(priv->host), "active-window-changed", G_CALLBACK(window_changed_cb), eventhandler);
 
-	savu_eventhandler_channel_start(priv->channel, priv->device, &error);
-	if (error) {
-		g_warning(_("Could not start chardev eventhandler: %s"), error->message);
-		g_clear_error(&error);
+	savu_eventhandler_channel_start(priv->channel, priv->device, &local_error);
+	if (local_error) {
+		g_warning(_("Could not start chardev eventhandler: %s"), local_error->message);
+		g_clear_error(&local_error);
 	}
 
 	priv->device_set_up = TRUE;
