@@ -38,15 +38,6 @@ enum {
 	TYON_CPI_STEP = 200,
 };
 
-typedef struct _TyonD TyonD;
-
-struct _TyonD {
-	guint8 report_id; /* TYON_REPORT_ID_D */
-	guint8 number;
-	guint8 data[1024];
-	guint16 checksum;
-};
-
 G_END_DECLS
 
 #endif
